@@ -119,16 +119,18 @@ sub run {
 
     _info "Repository forked:";
 
-    $data = $data->{repository};
-    print "  Name:          " . $data->{name} . "\n";
-    print "  Description:   " . $data->{description} . "\n";
-    print "  Owner:         " . $data->{owner} . "\n";
-    print "  Watchers:      " . $data->{watchers} . "\n";
-    print "  Created at:    " . $data->{created_at} . "\n";
-    print "  Pushed at:     " . $data->{pushed_at} . "\n";
-    print "  Fork:          " . $data->{'fork'} . "\n";
-    print "  URL:           " . $data->{url} . "\n";
-    print "  Homepage:      " . ($data->{homepage}||'') . "\n";
+    App::gh::Utils->print_repo_info($data->{repository});
+
+    # $data = $data->{repository};
+    # print "  Name:          " . $data->{name} . "\n";
+    # print "  Description:   " . $data->{description} . "\n";
+    # print "  Owner:         " . $data->{owner} . "\n";
+    # print "  Watchers:      " . $data->{watchers} . "\n";
+    # print "  Created at:    " . $data->{created_at} . "\n";
+    # print "  Pushed at:     " . $data->{pushed_at} . "\n";
+    # print "  Fork:          " . $data->{'fork'} . "\n";
+    # print "  URL:           " . $data->{url} . "\n";
+    # print "  Homepage:      " . ($data->{homepage}||'') . "\n";
 
 }
 
